@@ -90,7 +90,7 @@ class VideoWriter:
     def __enter__(self):
         self.write_pipe = (
             ffmpeg
-            .input('pipe:', format='rawvideo', pix_fmt='rgb24', s='{}x{}'.format(self.w, self.h))
+            .input('pipe:', format='rawvideo', pix_fmt='rgb24', loglevel='error', s='{}x{}'.format(self.w, self.h))
             .output(self.output_file, pix_fmt='yuv420p')
             .overwrite_output()
             .run_async(pipe_stdin=True)
